==> zego_plugin_adapter-2.8.0.tar.gz: lib/src/signaling/part/invitation.dart <==
part of '../interface.dart';

/// @nodoc
mixin ZegoSignalingPluginInvitationAPI {
  Future<ZegoSignalingPluginSendInvitationResult> sendInvitation({
    required List<String> invitees,
    required int timeout,
    String extendedData = '',
    ZegoSignalingPluginNotificationConfig? notificationConfig,
  });

  Future<ZegoSignalingPluginCancelInvitationResult> cancelInvitation({
    required String invitationID,
    required List<String> invitees,
    String extendedData = '',
    ZegoSignalingPluginIncomingInvitationCancelPushConfig? pushConfig,
  });

  Future<ZegoSignalingPluginResponseInvitationResult> refuseInvitation({
    required String invitationID,
    String extendedData = '',
  });

  Future<ZegoSignalingPluginResponseInvitationResult> acceptInvitation({
    required String invitationID,
    String extendedData = '',
  });
}

/// @nodoc
mixin ZegoSignalingPluginInvitationEvent {
  Stream<ZegoSignalingPluginInvitationUserStateChangedEvent>
      getInvitationUserStateChangedEventStream();

  Stream<ZegoSignalingPluginIncomingInvitationReceivedEvent>
      getIncomingInvitationReceivedEventStream();

  Stream<ZegoSignalingPluginIncomingInvitationCancelledEvent>
      getIncomingInvitationCancelledEventStream();

  Stream<ZegoSignalingPluginOutgoingInvitationAcceptedEvent>
      getOutgoingInvitationAcceptedEventStream();

  Stream<ZegoSignalingPluginOutgoingInvitationRejectedEvent>
      getOutgoingInvitationRejectedEventStream();

  Stream<ZegoSignalingPluginIncomingInvitationTimeoutEvent>
      getIncomingInvitationTimeoutEventStream();

  Stream<ZegoSignalingPluginOutgoingInvitationTimeoutEvent>
      getOutgoingInvitationTimeoutEventStream();
}

==> zego_plugin_adapter-2.8.5.tar.gz: lib/src/signaling/part/invitation.dart <==
part of '../interface.dart';

/// @nodoc
mixin ZegoSignalingPluginInvitationAPI {
  /// send Invitation
  Future<ZegoSignalingPluginSendInvitationResult> sendInvitation({
    required List<String> invitees,
    required int timeout,
    String extendedData = '',
    ZegoSignalingPluginPushConfig? pushConfig,
  });

  /// cancel Invitation
  Future<ZegoSignalingPluginCancelInvitationResult> cancelInvitation({
    required String invitationID,
    required List<String> invitees,
    String extendedData = '',
    ZegoSignalingPluginIncomingInvitationCancelPushConfig? pushConfig,
  });

  /// refuse Invitation
  Future<ZegoSignalingPluginResponseInvitationResult> refuseInvitation({
    required String invitationID,
    String extendedData = '',
  });

  /// accept Invitation
  Future<ZegoSignalingPluginResponseInvitationResult> acceptInvitation({
    required String invitationID,
    String extendedData = '',
  });
}

/// @nodoc
mixin ZegoSignalingPluginInvitationEvent {
  /// Invitation User State Changed Event Stream
  Stream<ZegoSignalingPluginInvitationUserStateChangedEvent>
      getInvitationUserStateChangedEventStream();

  /// Incoming Invitation Received Event Stream
  Stream<ZegoSignalingPluginIncomingInvitationReceivedEvent>
      getIncomingInvitationReceivedEventStream();

  /// Incoming Invitation Cancelled Event Stream
  Stream<ZegoSignalingPluginIncomingInvitationCancelledEvent>
      getIncomingInvitationCancelledEventStream();

  /// Outgoing Invitation Accepted Event Stream
  Stream<ZegoSignalingPluginOutgoingInvitationAcceptedEvent>
      getOutgoingInvitationAcceptedEventStream();

  /// Outgoing Invitation Rejected Event Stream
  Stream<ZegoSignalingPluginOutgoingInvitationRejectedEvent>
      getOutgoingInvitationRejectedEventStream();

  /// Incoming Invitation Timeout Event Stream
  Stream<ZegoSignalingPluginIncomingInvitationTimeoutEvent>
      getIncomingInvitationTimeoutEventStream();

  /// Outgoing Invitation Timeout Event Stream
  Stream<ZegoSignalingPluginOutgoingInvitationTimeoutEvent>
      getOutgoingInvitationTimeoutEventStream();
}
